==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Obrir imatge</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Costats bisellades</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombres paral·leles</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Colors</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fons:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Ressaltat:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>No es troba la imatge.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espereu un moment</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Carregant la imatge…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generant el trencaclosques…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Generant les peces…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Carregant el trancaclosques…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>El format de les dades és incorrecte</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>L&apos;elemento «%1» és desconegut</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>S&apos;ha produït un error en analitzar el fitxer XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Carregant les peces…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Recuperant les peces…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Col·locant les peces…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Joc</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Jocs actuals</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propietats de la imatge</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetes:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccioni l&apos;idioma del programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicii el programa per a que el canvi d&apos;idioma es faci efectiu.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Afegir imatge</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminar imatge</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propietats de la imatge</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 pieces</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiant les imátges…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·lar</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Voleu eliminar la imatge seleccionada?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Eliminar la imatge seleccionada?

Hi ha jocs desats que fan servir la imatge que voleu eliminar.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 pieces %2 %3% completat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Joc</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Voleu eliminar el joc seleccionat?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista general</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Afegir etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Eliminar etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sense etiqueta</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Totes les imatges</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sense títol %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Eliminar l&apos;etiqueta seleccionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ho sento</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ja existeix una etiqueta amb aquest nom.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Peces</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elegir...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Veure</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Am&amp;pliar</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Reduir</translation>
    </message>
    <message>
        <source>-</source>
        <translation>−</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Millor ajus&amp;t</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar R&amp;esum</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apariença…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controls</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Quant a &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controls</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Recollir les peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic esquerre o espai</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Col·locar les Peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seleccionar Peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrossegar a l&apos;esquerra</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Girar peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Click Dreta, Control + Clic Esquerra o R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrossegar trencaclosques:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic Roda del ratolí , Majúscules + Clic Esquerra, o Fletxes</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda del ratolí o +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Moure el cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Moure el cursor o W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Quant a Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un trencaclosques que fa servir tetrominoes com a peces</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>&amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicat sota llicència &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??&#xa0;%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1&#xa0;%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Seleccionau la versió d&apos;OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versió</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Obrir imatge</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Costats bisellades</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombres paral·leles</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Colors</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fons:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Ressaltat:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>No es troba la imatge.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espereu un moment</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Carregant la imatge…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generant el trencaclosques…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Generant les peces…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Carregant el trancaclosques…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>El format de les dades és incorrecte</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>L&apos;elemento «%1» és desconegut</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>S&apos;ha produït un error en analitzar el fitxer XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Carregant les peces…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Recuperant les peces…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Col·locant les peces…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Joc</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Jocs actuals</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propietats de la imatge</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetes:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccioni l&apos;idioma del programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicii el programa per a que el canvi d&apos;idioma es faci efectiu.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Afegir imatge</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminar imatge</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propietats de la imatge</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 pieces</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiant les imátges…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·lar</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 pieces %2 %3% completat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Joc</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Voleu eliminar el joc seleccionat?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista general</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Afegir etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Eliminar etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sense etiqueta</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Totes les imatges</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sense títol %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Eliminar l&apos;etiqueta seleccionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ho sento</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ja existeix una etiqueta amb aquest nom.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Peces</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elegir...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Veure</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Am&amp;pliar</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Reduir</translation>
    </message>
    <message>
        <source>-</source>
        <translation>−</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Millor ajus&amp;t</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar R&amp;esum</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apariença…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controls</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Quant a &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controls</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Recollir les peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic esquerre o espai</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Col·locar les Peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seleccionar Peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrossegar a l&apos;esquerra</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Girar peces:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Click Dreta, Control + Clic Esquerra o R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrossegar trencaclosques:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic Roda del ratolí , Majúscules + Clic Esquerra, o Fletxes</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda del ratolí o +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Moure el cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Moure el cursor o W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Quant a Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un trencaclosques que fa servir tetrominoes com a peces</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>&amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicat sota llicència &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
